@@ -3,7 +3,7 @@ from decimal import Decimal
 from django.core.validators import validate_comma_separated_integer_list
 from django.utils.translation import ugettext_lazy as _, pgettext_lazy
 from django_countries.serializer_fields import CountryField
-from django_iban.validators import IBANValidator
+from internationalflavor.iban import IBANValidator
 from internationalflavor.vat_number import VATNumberValidator
 from model_utils.choices import Choices
 from rest_framework import serializers
@@ -472,7 +472,6 @@ INAPP_AUDIENCE_FAMILIENVATER = 38
 INAPP_AUDIENCE_BEST_AGER = 39
 INAPP_AUDIENCE_BOSSHOME = 40
 INAPP_AUDIENCE_HOBBYKOCHE = 41
-INAPP_AUDIENCE_SONSTIGE = 42
 INAPP_AUDIENCE_CHOICES = Choices(
     (INAPP_AUDIENCE_GEBRAUCHTWAGEN_INTERESSENTEN, 'gebrauchtwagen_interessenten', _('Interested in used cars')),
     (INAPP_AUDIENCE_B2B_AUTOMOTIVE, 'b2b_automotive', _('B2B Automotive')),
@@ -518,7 +517,6 @@ INAPP_AUDIENCE_CHOICES = Choices(
     (INAPP_AUDIENCE_BEST_AGER, 'best_ager', _('Best ager')),
     (INAPP_AUDIENCE_BOSSHOME, 'bosshome', _('Boss@Home')),
     (INAPP_AUDIENCE_HOBBYKOCHE, 'hobbykoche', _('Amateur chefs')),
-    (INAPP_AUDIENCE_SONSTIGE, 'sonstige', _('Misc')),
 )
 
 
@@ -1431,7 +1429,7 @@ class OrderLineInAppSerializer(serializers.Serializer):
     description of the audience the ad should be targeted on
 
     """
-    target_audiences = serializers.MultipleChoiceField(choices=INAPP_AUDIENCE_CHOICES, required=True, allow_blank=True)
+    target_audiences = serializers.MultipleChoiceField(choices=INAPP_AUDIENCE_CHOICES, required=False, allow_blank=True)
 
     """
     textual representation of target audience requirements that are not represented by
@@ -1477,6 +1475,11 @@ class OrderLineInAppSerializer(serializers.Serializer):
     """
     ticket_id = serializers.CharField(max_length=20, required=True)
 
+    def validate(self, data):
+        if not data.get('target_audiences') and not data.get('other_target_audiences'):
+            raise serializers.ValidationError('target_audiences or other_target_audiences has to be set')
+        return data
+
 
 class OrderLineListingOpeningHoursSerializer(serializers.Serializer):
     """
